#!/usr/bin/env python
# $Id$
''' Simple script to ssh into a kvm host via hostname '''
import os, sys
from subprocess import Popen
import dns.name
from dns.resolver import Resolver

KVMDNS = '192.168.122.1'

def getaddr(hostname, dnsserver):
    ''' Get hostname from a specific dns server '''
    shortname = dns.name.from_text(hostname)
    resolver = Resolver(configure=False)
    resolver.nameservers.append(dnsserver)
    try:
        result = str(resolver.query(shortname).rrset).split()
    except:
        print "Unable to fetch address from hostname" + shortname
        sys.exit(1)
    addr = result.pop()
    return addr

def launchssh(addr, args='', username=''):
    ''' Spawn ssh process to target '''
    cmd = 'ssh'
    if username == '':
        username = os.getlogin()
    sshcmd = Popen("%s %s %s@%s" % (cmd, args, username, addr), shell=True)
    sts = os.waitpid(sshcmd.pid, 0)
    return sts

def main(argv):
    ''' Parse arguements for processing '''
    username = ''
    hostname = argv.pop()
    if '@' in hostname:
        username, hostname = hostname.split('@')
    argv.remove(argv[0])
    addr = getaddr(hostname, KVMDNS)
    launchssh(addr, ' '.join(argv), username)
    print "%s remote session closed." % hostname
    return

if __name__ == '__main__':
    main(sys.argv)
    sys.exit(0)

# vim:syntax=python
# vim:sw=4:softtabstop=4:expandtab
